/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    rc_fincen_config_update.sas
| PRODUCT: SAS Regulatory Console
| SYSTEM:  Windows, Unix
| DESC:    Program to update data for FinCEN reporting in hotfix 7.2HF4.
|             update to FinCEN schema Version 1.2 (12/17/2021)
|          1. increased length for occupation
|          2. cleaned up some special characters in descriptions
|          3. added F60
+------------------------------------------------------------------------------+
| USAGE:   Run this program using UTF-8 SAS.
+-------------+----------------------------------------------------------------+
| COMMENTS    | This program is executed by the regulatory console deployment scripts.
+-------------+----------+----------+------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2024 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/
options mprint varlenchk=nowarn;
%macro rc_fincen_schema_1_2;
    proc sql;
        /* Change birthDate to char to allow for custom validation */
        /* <xsd:pattern value="(19|20)[0-9][0-9](0[0-9]|1[0-2])(0[0-9]|1[0-9]|2[0-9]|3[01])|"/>  */
        update rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config))
        set target_field_num_flg='', target_sas_format_name='', source_field_type='BLANKTYPEDOB'
        where form_config_key=312
        and form_efile_record_id='party'
        and target_field_name = 'birthDate'
        ;
        /* Increase length of occupation */
        update rc_cfg.form_efile_field_config(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config))
        set target_field_length=50
        where form_config_key=312
        and upcase(target_field_name) = 'OCCUPATION'
        ;
        /* delete error C13 from ctrx errors */
        update rc_cfg.ctrx_fincen_error_code(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=ctrx_fincen_error_code))
        set error_desc = 'Deprecated: ' || error_desc
        where error_code = 'C13' and not index(lowcase(error_desc), 'deprecated')
        ;
        /* rename error A13 to F60 for ctrx errors */
        /* actually deprecate A13 and add F60      */
        update rc_cfg.ctrx_fincen_error_code(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=form_efile_field_config))
        set error_desc = 'Deprecated: ' || error_desc
        where error_code = 'A13' and not index(lowcase(error_desc), 'deprecated')
        ;

        /* add error F60 to ctrx errors */
        /* Error Record Code,Error Type Code,Error Text,Error Severity,Associated Element(s),Field Reference,,,*/
        /* batch,F60,The namespace prefix for the element is invalid.,Fatal,Misc.,Misc.,,,  */
        /* delete first to allow rerunning */
        delete from rc_cfg.ctrx_fincen_error_code(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=ctrx_fincen_error_code))
        where error_code = 'F60'
        ;
        data new_ctrx_fincen_error_code;
            if 0 then set rc_cfg.ctrx_fincen_error_code(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=ctrx_fincen_error_code));
            assoc_element = '';
            error_code = 'F60';
            error_desc = 'The namespace prefix for the element is invalid.';
            error_record_type = 'filer';
            error_type_code = 'F';
            error_type_text = 'Fatal    Misc.';
            field_reference = 'N/A';
            output;
            stop;
        run;

        proc append base = rc_cfg.ctrx_fincen_error_code(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=ctrx_fincen_error_code))
                    data = new_ctrx_fincen_error_code;
        run;

        /* add error F60 to doepx errors */
        /* Error Record Code,Error Type Code,Error Text,Error Severity,Associated Element(s),Field Reference,,,*/
        /* batch,F60,The namespace prefix for the element is invalid.,Fatal,Misc.,Misc.,,,  */
        /* delete first to allow rerunning */
        proc sql;
        delete from rc_cfg.doepx_fincen_error_code(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=doepx_fincen_error_code))
        where error_code = 'F60'
        ;
        data new_doepx_fincen_error_code;
            if 0 then set rc_cfg.doepx_fincen_error_code(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=doepx_fincen_error_code));
            assoc_element = '';
            error_code = 'F60';
            error_desc = 'The namespace prefix for the element is invalid.';
            error_record_type = 'filer';
            error_type_code = 'F';
            error_type_text = 'Fatal	Misc.';
            field_reference = 'N/A';
            output;
            stop;
        run;

        proc append base = rc_cfg.doepx_fincen_error_code(%fcf_get_ds_opts(lib_name=rc_cfg, ds_name=doepx_fincen_error_code))
                    data = new_doepx_fincen_error_code;
        run;

        /* update the table rc_db.ctrx_party to change the birthDate column to char */

        proc sql noprint;
            select strip(type) into :type from sashelp.vcolumn where libname='RC_DB' and memname='CTRX_PARTY' and name='birthDate';
        quit;
        %put column type of birthDate &=type.;
        %if "&type" ne "char" %then %do;
        proc sql noprint;
            alter table rc_db.ctrx_party(%fcf_get_ds_opts(lib_name=rc_db, ds_name=ctrx_party))
          /* create char column and populate */
            add birthDateChar char length=10;
            update rc_db.ctrx_party(%fcf_get_ds_opts(lib_name=rc_db, ds_name=ctrx_party))
            set birthDateChar = put(birthDate, yymmdd10.);
          /* replace old num column with char version */
            alter table rc_db.ctrx_party(%fcf_get_ds_opts(lib_name=rc_db, ds_name=ctrx_party))
            drop birthDate;
            alter table rc_db.ctrx_party(%fcf_get_ds_opts(lib_name=rc_db, ds_name=ctrx_party))
            add birthDate char length=10;
            update rc_db.ctrx_party(%fcf_get_ds_opts(lib_name=rc_db, ds_name=ctrx_party))
            set birthDate = birthDateChar;
            alter table rc_db.ctrx_party(%fcf_get_ds_opts(lib_name=rc_db, ds_name=ctrx_party))
            drop birthDateChar;
        %end;
    quit;

%rc_efile_gen_macro_xpose_node(form_config_key=312 , form_type_code=CTRX)

%mend;

%rc_fincen_schema_1_2;
