/* MAINDOC
+------------------------------------------------------------------------------+
| NAME:    fcf_load_watch_list.sas
| PRODUCT: SAS Compliance Solutions
| SYSTEM:  Windows, Unix
| DESC:    Load Watch List
+------------------------------------------------------------------------------+
MAINDOCEND */

/*-------------------------------------------------------------------
 * Copyright (c) 2012-2024 by SAS Institute Inc., Cary, NC 27513 USA
 *  ---All Rights Reserved.
 *-------------------------------------------------------------------*/
 
%macro fcf_load_watch_list;

  /* Get the current runasofdate */
  %fcf_get_runasofdate;
  %put NOTE: FCF: RUNASOFDATE: &runasofdate;


  /****************************************************************************/
  /* DFAT - Australian Department of Foreign Affairs and Trade                */
  /****************************************************************************/

  /* USER SETTINGS */
  %let DFAT_PROCESS=Y;
  %let excel_sheet=;
  %let dfat_file=&FCFLAND./regulation8_consolidated.xls;

  %if %upcase(&DFAT_PROCESS) eq Y %then %do;
     %fcf_wl_dfat_process
       (
        dfat_file=&dfat_file,
        excel_sheet=
       );
  %end;


  /****************************************************************************/
  /* DWJN - Dow Jones Watchlist                                               */
  /****************************************************************************/

  /* USER SETTINGS */
  %let DWJN_PROCESS=N;
  %let dwjn_file=&FCFLAND./file-name;
  %let allow_invalid=N;
  %let load_type=FULL;
  %let bulkload=;

  %if %upcase(&DWJN_PROCESS) eq Y %then %do;
     %fcf_wl_dwjn_process
       (
        dwjn_file=&dwjn_file,
        allow_invalid=&allow_invalid,
        load_type=&load_type
       );
  %end;


  /****************************************************************************/
  /* EUFS - European Union, Common Foreign and Security Policy (CFSP)         */
  /****************************************************************************/

  /* USER SETTINGS */
  %let EUFS_PROCESS=N;
  %let eufs_file=&FCFLAND./file-name;
  %let eufs_map=&fcf_xml_map_path/fcf_wl_eufs.map;

  %if %upcase(&EUFS_PROCESS) eq Y %then %do;
     %fcf_wl_eufs_process
       (
        eufs_file=&eufs_file,
        eufs_map=&eufs_map
       );
  %end;


  /****************************************************************************/
  /* HMT - U.K. HM Treasury                                                   */
  /****************************************************************************/

  /* USER SETTINGS */
  %let HMT_PROCESS=N;
  %let hmt_file=&FCFLAND./file-name;
  %let textsize=10000;
  %let allow_invalid=N;

  %if %upcase(&HMT_PROCESS) eq Y %then %do;
     %fcf_wl_hmt_process
       (
        hmt_file=&hmt_file,
        textsize=&textsize,
        allow_invalid=&allow_invalid
       );
  %end;


  /****************************************************************************/
  /* NBCI - National Bureau of Criminal Intelligence, New Zealand Police      */
  /****************************************************************************/

  /* USER SETTINGS */
  %let NBCI_PROCESS=N;
  %let nbci_file=&FCFLAND./file-name;
  %let bulkload=;

  %if %upcase(&NBCI_PROCESS) eq Y %then %do;
     %fcf_wl_nbci_process (nbci_file=&nbci_file);
  %end;


  /****************************************************************************/
  /* OFAC - U.S.Treasury - Office of Foreign Assets Control                   */
  /****************************************************************************/

  /* USER SETTINGS */
  %let OFAC_PROCESS=N;
  %let ofac_sdn_file=&FCFLAND./file-name;
  %let ofac_add_file=&FCFLAND./file-name;
  %let ofac_alt_file=&FCFLAND./file-name;
  %let allow_invalid=N;
  %let bulkload=;

  %if %upcase(&OFAC_PROCESS) eq Y %then %do;
     %fcf_wl_ofac_process
       (
        ofac_sdn_file=&ofac_sdn_file,
        ofac_add_file=&ofac_add_file,
        ofac_alt_file=&ofac_alt_file,
        allow_invalid=&allow_invalid
       );
  %end;


  /****************************************************************************/
  /* OSFI - Office of the Superintendent of Financial Institutions Canada     */
  /****************************************************************************/

  /* USER SETTINGS */
  %let OSFI_PROCESS=N;
  %let osfi_entstld_file=&FCFLAND./file-name;
  %let osfi_indstld_file=&FCFLAND./file-name;
  %let textsize=10000;
  %let allow_invalid=N;

  %if %upcase(&OSFI_PROCESS) eq Y %then %do;
     %fcf_wl_osfi_process
       (
        osfi_entstld_file=&osfi_entstld_file,
        osfi_indstld_file=&osfi_indstld_file,
        textsize=&textsize,
        allow_invalid=&allow_invalid
       );
  %end;


  /****************************************************************************/
  /* UNSC - United Nations Security Council                                   */
  /****************************************************************************/

  /* USER SETTINGS */
  %let UNSC_PROCESS=N;
  %let unsc_file=&FCFLAND./file-name;
  %let unsc_map=&fcf_xml_map_path/fcf_wl_unsc.map;
  %let bulkload=;

  %if %upcase(&UNSC_PROCESS) eq Y %then %do;
     %fcf_wl_unsc_process
       (
        unsc_file=&unsc_file,
        unsc_map=&unsc_map
       );
  %end;


  /****************************************************************************/
  /* WCHK - World-Check                                                       */
  /****************************************************************************/

  /* USER SETTINGS */
  %let WCHK_PROCESS=N;
  %let wchk_file=&FCFLAND./file-name;
  %let textsize=10000;
  %let allow_invalid=N;
  %let load_type=FULL;
  %let delete_file=;

  %if %upcase(&WCHK_PROCESS) eq Y %then %do;
     %fcf_wl_wchk_process
       (
        wchk_file=&wchk_file,
        textsize=&textsize,
        allow_invalid=&allow_invalid,
        load_type=&load_type,
        delete_file=&delete_file
       );
  %end;

%mend fcf_load_watch_list;
